[GRASS-SVN] r37244 - grass/trunk/imagery/i.atcorr

svn_grass at osgeo.org svn_grass at osgeo.org
Sat May 16 12:41:59 EDT 2009


Author: neteler
Date: 2009-05-16 12:41:59 -0400 (Sat, 16 May 2009)
New Revision: 37244

Modified:
   grass/trunk/imagery/i.atcorr/main.cpp
Log:
downsize the static cache for 32bit CPUs

Modified: grass/trunk/imagery/i.atcorr/main.cpp
===================================================================
--- grass/trunk/imagery/i.atcorr/main.cpp	2009-05-15 14:47:28 UTC (rev 37243)
+++ grass/trunk/imagery/i.atcorr/main.cpp	2009-05-16 16:41:59 UTC (rev 37244)
@@ -29,6 +29,7 @@
 
 * Addition of IRS-1C LISS, Feb 2009: Markus Neteler
 
+TODO: use dynamic allocation for TiCache 
 ***************************************************************************/
 
 #include <cstdlib>
@@ -131,7 +132,9 @@
 {
     enum TICacheSize
     {
-        MAX_TIs = 8192 /* this value is a guess, increase it if in general more categories are used */
+        MAX_TIs = 4096 /* this value is a guess, increase it if in general 
+                        * more categories are used. TODO: use dynamic allocation
+                        * since 4096 is the limit on 32bit */
     };
     TransformInput tis[MAX_TIs];
     float alts[MAX_TIs];
@@ -173,8 +176,9 @@
 {
     enum TIMapSize
     {
-	MAX_TICs = 8192  /* this value is a guess. It means that <size> TI's will be 
-                          * the max combinations of vis/alt pairs */
+	MAX_TICs = 4096  /* this value is a guess. It means that <size> TI's will be 
+                          * the max combinations of vis/alt pairs. TODO: use dynamic allocation
+                          * since 4096 is the limit on 32bit */
     };
 
     TICache tic[MAX_TICs]; /* array of TICaches */



More information about the grass-commit mailing list